from _freeorion_tools import *
from extend_freeorion_AI_interface import patch_interface
from interactive_shell import handle_debug_chat
from timers import AITimer
from handlers import init_handlers
